@@ -20,10 +20,8 @@
 #include "kbugreport.h"
 
 #include <QProcess>
-#include <QCoreApplication>
 #include <QDialogButtonBox>
 #include <QPushButton>
-#include <QLayout>
 #include <QRadioButton>
 #include <QGroupBox>
 #include <QLocale>
@@ -36,6 +34,8 @@
 #include <QLineEdit>
 #include <QStandardPaths>
 #include <QDebug>
+#include <QHBoxLayout>
+#include <QGridLayout>
 
 #include <kaboutdata.h>
 #include <kconfig.h>
@@ -51,6 +51,8 @@
 #include "systeminformation_p.h"
 #include "config-xmlgui.h"
 
+#include <array>
+
 class KBugReportPrivate
 {
 public:
@@ -113,7 +115,7 @@ KBugReport::KBugReport(const KAboutData &aboutData, QWidget *_parent)
     d->bugDestination = KBugReportPrivate::CustomEmail;
 
     const QString bugAddress = d->m_aboutData.bugAddress();
-    if (bugAddress == QStringLiteral("submit@bugs.kde.org")) {
+    if (bugAddress == QLatin1String("submit@bugs.kde.org")) {
         // This is a core KDE application -> redirect to the web form
         d->bugDestination = KBugReportPrivate::BugsKdeOrg;
     } else if (!QUrl(bugAddress).scheme().isEmpty()) {
@@ -212,8 +214,7 @@ KBugReport::KBugReport(const KAboutData &aboutData, QWidget *_parent)
     if (d->m_strVersion.isEmpty()) {
         d->m_strVersion = i18n("no version set (programmer error)");
     }
-    d->kde_version = QStringLiteral(KXMLGUI_VERSION_STRING);
-    d->kde_version += QStringLiteral(", ") + QLatin1String(XMLGUI_DISTRIBUTION_TEXT);
+    d->kde_version = QStringLiteral(KXMLGUI_VERSION_STRING) + QLatin1String(", ") + QStringLiteral(XMLGUI_DISTRIBUTION_TEXT);
     if (d->bugDestination != KBugReportPrivate::BugsKdeOrg) {
         d->m_strVersion += QLatin1Char(' ') + d->kde_version;
     }
@@ -240,19 +241,25 @@ KBugReport::KBugReport(const KAboutData &aboutData, QWidget *_parent)
     if (d->bugDestination == KBugReportPrivate::CustomEmail) {
         // Severity
         d->m_bgSeverity = new QGroupBox(i18n("Se&verity"), this);
-        static const char *const sevNames[5] = { "critical", "grave", "normal", "wishlist", "i18n" };
-        const QString sevTexts[5] = { i18n("Critical"), i18n("Grave"), i18nc("normal severity", "Normal"), i18n("Wishlist"), i18n("Translation") };
+
+        struct SeverityData { QString name; QString text; };
+        const std::array<SeverityData, 5> severityData = { {
+            { QStringLiteral("critical"), i18n("Critical") },
+            { QStringLiteral("grave"),    i18n("Grave") },
+            { QStringLiteral("normal"),   i18nc("normal severity", "Normal") },
+            { QStringLiteral("wishlist"), i18n("Wishlist") },
+            { QStringLiteral("i18n"),     i18n("Translation") },
+        } };
+
         QHBoxLayout *severityLayout = new QHBoxLayout(d->m_bgSeverity);
-        for (int i = 0; i < 5; i++) {
+        for (auto& severityDatum : severityData) {
             // Store the severity string as the name
-            QRadioButton *rb = new QRadioButton(sevTexts[i], d->m_bgSeverity);
-            rb->setObjectName(QLatin1String(sevNames[i]));
+            QRadioButton *rb = new QRadioButton(severityDatum.text, d->m_bgSeverity);
+            rb->setObjectName(severityDatum.name);
             d->severityButtons.append(rb);
             severityLayout->addWidget(rb);
-            if (i == 2) {
-                rb->setChecked(true);    // default : "normal"
-            }
         }
+        d->severityButtons[2]->setChecked(true); // default : "normal"
 
         lay->addWidget(d->m_bgSeverity);
 
@@ -369,7 +376,7 @@ void KBugReportPrivate::_k_appChanged(int i)
     QString appName = appcombo->itemText(i);
     int index = appName.indexOf(QLatin1Char('/'));
     if (index > 0) {
-        appName = appName.left(index);
+        appName.truncate(index);
     }
     //qCDebug(DEBUG_KXMLGUI) << "appName " << appName;
 
@@ -423,7 +430,7 @@ void KBugReportPrivate::_k_slotSetFrom()
     } else {
         QString name = emailSettings.getSetting(KEMailSettings::RealName);
         if (!name.isEmpty()) {
-            fromaddr = name + QLatin1String(" <") + fromaddr + QLatin1String(">");
+            fromaddr = name + QLatin1String(" <") + fromaddr + QLatin1Char('>');
         }
     }
     m_from->setText(fromaddr);
@@ -476,7 +483,7 @@ void KBugReport::accept()
         QString msg = i18n("Unable to send the bug report.\n"
                            "Please submit a bug report manually....\n"
                            "See https://bugs.kde.org/ for instructions.");
-        KMessageBox::error(this, msg + QStringLiteral("\n\n") + d->lastError);
+        KMessageBox::error(this, msg + QLatin1String("\n\n") + d->lastError);
         return;
     }
 
@@ -523,21 +530,25 @@ QString KBugReport::text() const
         if (bodyText[bodyText.length() - 1] != QLatin1Char('\n')) {
             bodyText += QLatin1Char('\n');
         }
-    if (severity == QStringLiteral("i18n") && QLocale().language() != QLocale::system().language()) {
+    if (severity == QLatin1String("i18n") && QLocale().language() != QLocale::system().language()) {
         // Case 1 : i18n bug
-        QString package = QStringLiteral("i18n_%1").arg(QLocale::languageToString(QLocale().language()));
-        package = package.replace(QLatin1Char('_'), QLatin1Char('-'));
-        return QStringLiteral("Package: %1").arg(package) +
-               QStringLiteral("\nApplication: %1\nVersion: %2\n").arg(appname, d->m_strVersion) +
+        QString package = QLatin1String("i18n_") + QLocale::languageToString(QLocale().language());
+        package.replace(QLatin1Char('_'), QLatin1Char('-'));
+        return QLatin1String("Package: ") + package +
+               QLatin1String("\nApplication: ") + appname +
+               QLatin1String("\nVersion: ") + d->m_strVersion +
                                    // not really i18n's version, so better here IMHO
-                                   os + QLatin1String("\n") + bodyText;
+               QLatin1Char('\n') + os +
+               QLatin1Char('\n') + bodyText;
     } else {
-        appname = appname.replace(QLatin1Char('_'), QLatin1Char('-'));
+        appname.replace(QLatin1Char('_'), QLatin1Char('-'));
         // Case 2 : normal bug
-        return QStringLiteral("Package: %1\nVersion: %2\nSeverity: %3\n")
-               .arg(appname, d->m_strVersion, severity) +
-               QStringLiteral("Compiler: %1\n").arg(QStringLiteral(XMLGUI_COMPILER_VERSION)) +
-               os + QLatin1String("\n") + bodyText;
+        return QLatin1String("Package: ") + appname +
+               QLatin1String("\nVersion: ") + d->m_strVersion +
+               QLatin1String("\nSeverity: ") + severity +
+               QLatin1String("\nCompiler: ") + QStringLiteral(XMLGUI_COMPILER_VERSION) +
+               QLatin1Char('\n') + os +
+               QLatin1Char('\n') + bodyText;
     }
 }
 
