@@ -27,7 +27,9 @@
 #include "kmainwindow.h"
 
 #include "kmainwindow_p.h"
+#ifdef QT_DBUS_LIB
 #include "kmainwindowiface_p.h"
+#endif
 #include "ktoolbarhandler_p.h"
 #include "khelpmenu.h"
 #include "ktoolbar.h"
@@ -37,16 +39,16 @@
 #include <QObject>
 #include <QTimer>
 #include <QCloseEvent>
-#include <QDesktopWidget>
 #include <QDockWidget>
-#include <QLayout>
 #include <QMenuBar>
 #include <QSessionManager>
 #include <QStatusBar>
 #include <QStyle>
 #include <QWidget>
 #include <QWindow>
+#ifdef QT_DBUS_LIB
 #include <QDBusConnection>
+#endif
 
 #include <ktoggleaction.h>
 #include <kaboutdata.h>
@@ -135,14 +137,15 @@ void KMWSessionManager::saveState(QSessionManager &sm)
     KConfigGui::setSessionConfig(sm.sessionId(), sm.sessionKey());
 
     KConfig *config = KConfigGui::sessionConfig();
-    if (!KMainWindow::memberList().isEmpty()) {
+    const auto windows = KMainWindow::memberList();
+    if (!windows.isEmpty()) {
         // According to Jochen Wilhelmy <digisnap@cs.tu-berlin.de>, this
         // hook is useful for better document orientation
-        KMainWindow::memberList().at(0)->saveGlobalProperties(config);
+        windows.at(0)->saveGlobalProperties(config);
     }
 
     int n = 0;
-    foreach (KMainWindow *mw, KMainWindow::memberList()) {
+    for (KMainWindow *mw : windows) {
         n++;
         mw->savePropertiesInternal(config, n);
     }
@@ -186,7 +189,8 @@ void KMWSessionManager::commitData(QSessionManager &sm)
          Worst of all, that is a real problem with ksmserver - it will not save
          applications that quit on their own in state save-yourself-done.
      */
-    foreach (KMainWindow *window, KMainWindow::memberList()) {
+    const auto windows = KMainWindow::memberList();
+    for (KMainWindow *window : windows) {
         if (window->testAttribute(Qt::WA_WState_Hidden)) {
             continue;
         }
@@ -318,7 +322,7 @@ void KMainWindowPrivate::polish(KMainWindow *q)
     for (;;) {
         const QList<QWidget *> list = qApp->topLevelWidgets();
         bool found = false;
-        foreach (QWidget *w, list) {
+        for (QWidget *w : list) {
             if (w != q && w->objectName() == s) {
                 found = true;
                 break;
@@ -349,11 +353,13 @@ void KMainWindowPrivate::polish(KMainWindow *q)
         }
     }
 
+#ifdef QT_DBUS_LIB
     QDBusConnection::sessionBus().registerObject(dbusName, q, QDBusConnection::ExportScriptableSlots |
             QDBusConnection::ExportScriptableProperties |
             QDBusConnection::ExportNonScriptableSlots |
             QDBusConnection::ExportNonScriptableProperties |
             QDBusConnection::ExportAdaptors);
+#endif
 }
 
 void KMainWindowPrivate::setSettingsDirty(CallCompression callCompression)
@@ -487,8 +493,8 @@ void KMainWindow::setCaption(const QString &caption)
 void KMainWindow::setCaption(const QString &caption, bool modified)
 {
     QString title = caption;
-    if (!title.contains(QStringLiteral("[*]")) && !title.isEmpty()) { // append the placeholder so that the modified mechanism works
-        title.append(QStringLiteral(" [*]"));
+    if (!title.contains(QLatin1String("[*]")) && !title.isEmpty()) { // append the placeholder so that the modified mechanism works
+        title.append(QLatin1String(" [*]"));
     }
     setPlainCaption(title);
     setWindowModified(modified);
@@ -613,7 +619,8 @@ void KMainWindow::saveMainWindowSettings(KConfigGroup &cg)
     }
 
     int n = 1; // Toolbar counter. toolbars are counted from 1,
-    foreach (KToolBar *toolbar, toolBars()) {
+    const auto toolBars = this->toolBars();
+    for (KToolBar *toolbar : toolBars) {
         QByteArray groupName("Toolbar");
         // Give a number to the toolbar, but prefer a name if there is one,
         // because there's no real guarantee on the ordering of toolbars
@@ -694,7 +701,8 @@ void KMainWindow::applyMainWindowSettings(const KConfigGroup &cg)
     }
 
     int n = 1; // Toolbar counter. toolbars are counted from 1,
-    foreach (KToolBar *toolbar, toolBars()) {
+    const auto toolBars = this->toolBars();
+    for (KToolBar *toolbar : toolBars) {
         QByteArray groupName("Toolbar");
         // Give a number to the toolbar, but prefer a name if there is one,
         // because there's no real guarantee on the ordering of toolbars
@@ -826,8 +834,6 @@ bool KMainWindow::event(QEvent *ev)
         if (dock) {
             connect(dock, &QDockWidget::dockLocationChanged,
                     this, &KMainWindow::setSettingsDirty);
-            connect(dock, &QDockWidget::visibilityChanged,
-                    this, &KMainWindow::setSettingsDirty, Qt::QueuedConnection);
             connect(dock, &QDockWidget::topLevelChanged,
                     this, &KMainWindow::setSettingsDirty);
 
@@ -853,8 +859,6 @@ bool KMainWindow::event(QEvent *ev)
         if (dock) {
             disconnect(dock, &QDockWidget::dockLocationChanged,
                        this, &KMainWindow::setSettingsDirty);
-            disconnect(dock, &QDockWidget::visibilityChanged,
-                       this, &KMainWindow::setSettingsDirty);
             disconnect(dock, &QDockWidget::topLevelChanged,
                        this, &KMainWindow::setSettingsDirty);
             dock->removeEventFilter(k_ptr->dockResizeListener);
